This is a live mirror of the Perl 5 development currently hosted at https://github.com/perl/perl5
Upgrade Encode from 2.39 to 2.40
[perl5.git] / parser.h
index 3cb3135..4ef4608 100644 (file)
--- a/parser.h
+++ b/parser.h
@@ -15,7 +15,7 @@ typedef struct {
     YYSTYPE val;    /* semantic value */
     short   state;
     I32     savestack_ix;      /* size of savestack at this state */
-    AV     *comppad; /* value of PL_comppad when this value was created */
+    CV     *compcv; /* value of PL_compcv when this value was created */
 #ifdef DEBUGGING
     const char  *name; /* token/rule name for -Dpv */
 #endif
@@ -106,5 +106,17 @@ typedef struct yy_parser {
     char       tokenbuf[256];
 
 } yy_parser;
-    
 
+/* flags for lexer API */
+#define LEX_STUFF_UTF8         0x00000001
+#define LEX_KEEP_PREVIOUS      0x00000002
+
+/*
+ * Local variables:
+ * c-indentation-style: bsd
+ * c-basic-offset: 4
+ * indent-tabs-mode: t
+ * End:
+ *
+ * ex: set ts=8 sts=4 sw=4 noet:
+ */